@@ -1,7 +1,7 @@
 /*
  *  alarmtimewidget.cpp  -  alarm date/time entry widget
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -493,6 +493,15 @@ void AlarmTimeWidget::enableAnyTime(bool enable)
     }
 }
 
+/******************************************************************************
+* Set the keyboard focus to the time from now field.
+*/
+void AlarmTimeWidget::focusTimeFromNow()
+{
+    if (!mAtTimeRadio->isChecked())
+        mDelayTimeEdit->setFocus();
+}
+
 /******************************************************************************
 * Called every minute to update the alarm time data entry fields.
 * If the maximum date/time has been reached, a 'pastMax()' signal is emitted.
