@@ -9,7 +9,6 @@
 #include "undo.h"
 
 #include "functions.h"
-#include "resourcescalendar.h"
 #include "resources/resources.h"
 #include "lib/messagebox.h"
 #include "kalarmcalendar/alarmtext.h"
@@ -409,7 +408,7 @@ bool Undo::undo(int i, Undo::Type type, QWidget* parent, const QString& action)
         case UndoItem::ERR_PROG:       err = i18nc("@info", "Program error");  break;
         default:                       err = i18nc("@info", "Unknown error");  break;
     }
-    KAMessageBox::sorry(parent, i18nc("@info Undo-action: message", "%1: %2", action, err));
+    KAMessageBox::error(parent, i18nc("@info Undo-action: message", "%1: %2", action, err));
     return false;
 }
 
